"""
This cli.py is just an interface that collect and manage all the actions,
which help centralize the logic for handling variaous commands and make it easier to maintain 
and expand in the future. 

There are two parts need to be edited to make CLI works. 
1. cli.py: it is an adapter between CLI listener in `setup.py` and the functionalities from subpackages,
2. setup.py: the `entry_points` attribute setup the listeners and the related keywords, that subsequently
the user can use them in their terminal to trigger those functionalities. 
"""


from subpackage.ConfigJSONHandler import ConfigJSONHandler
from subpackage.GitPushManager import GitPushManager

import argparse

def _check_datastore_location():
    """This function would be optionally used by multiple CLI actions. """
    datastore_json_path = ConfigJSONHandler.check_initial_setup_then_get_datastore_json_address()

def cli_lpush():
    parser = argparse.ArgumentParser(description='Push changes to Git')
    args = parser.parse_args()
    GitPushManager().lpush() 

def main():
    parser = argparse.ArgumentParser(description='Command-line interface for gites package')
    subparsers = parser.add_subparsers(dest='command', help='Available commands')

    # Create a subparser for the 'push' command
    push_parser = subparsers.add_parser('push', help='Push changes to Git')
    push_parser.set_defaults(func=cli_lpush)

    args = parser.parse_args()

    if hasattr(args, 'func'):
        args.func()

if __name__ == "__main__":
    cli_lpush()


from setuptools import setup, find_packages

setup(
    name='gites',
    version='0.1.2',
    description='gites is the home of all developers. It provides bulk clone, bulk push, bulk pull etc. Contact me with my discord ID: pakkin.lau',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Pak Kin LAU',
    author_email='kinlau529@gmail.com',
    url='https://github.com/pakkinlau/gites',
    packages=find_packages(),  
    # ["."] or find_package(): Include all packages under the current directory 
    # before: find_packages(),
    install_requires=[],
    entry_points={
        "console_scripts": [
            "gites-lpush=my_package.cli:cli_lpush",
        ]# we define multiple entry points like this here. 
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
    ],
)